import random

def rand_a_int(a: int, b: int) -> int:
    return random.randint(a, b)

def rand_some_int(a: int, b: int, amount: int) -> tuple:
    res = []
    for i in range(0, amount):
        tmp = rand_a_int(a, b)
        res.append(tmp)
    return tuple(res)

def rand_bool() -> bool:
    return bool(rand_a_int(0,1))


import base64
from . import numeration as n

_d = {
    '嗷': '0',
    '呜': '1',
    '汪': '2'
}
_e = {
    '0': '嗷',
    '1': '呜',
    '2': '汪'
}

#将字符串加密为狗语
def enc(inp: str) -> str:
    tmp = inp.encode(encoding='utf-8')
    tmp = base64.b16encode(tmp)
    tmp = int(tmp, 16)
    tmp = n.num(tmp, 3)
    tmp = ''.join([_e[each] for each in tmp])
    return tmp

#狗语解密
def dec(inp: str) -> str:
    tmp = ''.join([_d[each] for each in inp])
    tmp = int(tmp, 3)
    tmp = hex(tmp)[2:].upper()
    tmp = base64.b16decode(tmp)
    tmp = tmp.decode(encoding='utf-8')
    return tmp


import json
import os

class JsonData:
    def __init__(self, path: str):
        self.path = path
        os.makedirs(os.path.dirname(path), exist_ok=True)
        if not os.path.exists(path):
            self.writes('')

    def reads(self) -> str:
        with open(self.path, 'r', encoding='utf-8') as f:
            data = f.read()
        return data

    def writes(self, to_write: str):
        with open(self.path, 'w+', encoding='utf-8') as f:
            f.write(to_write)

    def gets(self, keys: tuple):
        tmp = self.read()
        for each in keys:
            if isinstance(tmp, dict):
                tmp = tmp.get(each)
            else:
                return None
        return tmp
    
    #这个函数全都是魔法 我也不知道我写的啥 但是能跑而且跑得好像还行
    def sets(self, keys: tuple, value):
        data = self.read()
        for i in range(1, len(keys)+1):
            s = keys[0:i]
            loc = ''.join([f'[\'{x}\']' for x in s])
            loc = f'data{loc}'
            try:
                tmp = eval(loc)
            except KeyError:
                tmp = None
            if i == len(keys):
                exec(f'{loc} = value')
                break
            elif not isinstance(tmp, dict):
                exec(f'{loc} = ' + '{}')
        self.write(data)
    
    def read(self) -> object:
        data_str = self.reads()
        if data_str == '':
            data_str = '{}'
            self.writes(data_str)
        return json.loads(data_str)

    def write(self, to_write: object):
        return self.writes(json.dumps(to_write, indent=4))
    
    def get(self, key: str):
        keys = key.split('.')
        return self.gets(keys)

    def set(self, key: str, value):
        keys = key.split('.')
        return self.sets(keys, value)

    def __str__(self):
        return self.reads()

if __name__ == '__main__':
    jconf = JsonData('src/conf.json')
    jconf.set('settings.port', 3389)
    port = jconf.get('settings.port')


#给一个int 将其转换为radix进制数的形式并返回str
def num(inp: int, radix: int) -> str:
    if radix < 0 or radix > 36: 
        raise ValueError('Radix should be in [2, 36]')
    E = '0123456789abcdefghijklmnopqrstuvwxyz'
    tmp = ''
    d = inp
    while True:
        n = d % radix
        d = d // radix
        tmp = E[n] + tmp
        if d == 0:
            break
    return tmp

if __name__ == '__main__':
    print(num(114514, 2), bin(114514))
    print(num(114514, 8), oct(114514))
    print(num(114514, 16), hex(114514))
    print(i := num(114514, 3), int(i, 3))


from setuptools import setup, find_packages

setup(
    name = "inukit",
    packages = ['inukit'],
    version = "0.9",
    license = 'MIT',
    description = "Kit by & for inuEbisu",
    author = "inuEbisu",
    author_email = "inuebisu@qq.com",
    url = "https://inuebisu.cn", 
    keywords = ['inukit']
)


import time

def timestamp_now() -> int:
    return int(time.mktime(time.localtime()))

def timestamp(
    string: str,
    form: str = '%Y-%m-%d %H:%M:%S'
) -> int:
    return int(time.mktime(time.strptime(string, form)))

def natural_date(
    timestamp: int, 
    form: str = '%Y-%m-%d %H:%M:%S'
) -> str:
    if timestamp < 0:
        return None
    res = time.localtime(int(timestamp))
    return time.strftime(form, res)

def date_now(form: str = '%Y-%m-%d %H:%M:%S'):
    return natural_date(timestamp_now(), form)

def natural_time(timestamp: int) -> str:
    s = timestamp % 60
    m = (timestamp % 3600) // 60
    h = timestamp // 3600
    return f'{h} h {m} m {s} s'

if __name__ == '__main__':
    print(timestamp_now())
    print(date_now('%m-%d-%Y %H:%M:%S'))
    print(timestamp('2016-03-12 08:00:00'))
    print(natural_date(1457740800, '%Y-%m-%d'))
    print(natural_time(timestamp('2020-03-12 14:15:16') - timestamp('2016-05-20 22:32:12')))